@@ -15,28 +15,24 @@
 
 import logging
 
-from osc_lib.cli import format_columns
 from osc_lib.command import command
 from osc_lib import exceptions
 from osc_lib import utils
 
 from openstackclient.i18n import _
+from openstackclient.network import common
 from openstackclient.network import sdk_utils
 
 
 LOG = logging.getLogger(__name__)
 
 
-_formatters = {
-    'location': format_columns.DictColumn,
-}
-
-
 def _get_columns(item):
     return sdk_utils.get_osc_show_columns_for_sdk_resource(item, {})
 
 
-class CreateNetworkSegment(command.ShowOne):
+class CreateNetworkSegment(command.ShowOne,
+                           common.NeutronCommandWithExtraArgs):
     _description = _("Create new network segment")
 
     def get_parser(self, prog_name):
@@ -94,9 +90,11 @@ class CreateNetworkSegment(command.ShowOne):
             attrs['physical_network'] = parsed_args.physical_network
         if parsed_args.segment is not None:
             attrs['segmentation_id'] = parsed_args.segment
+        attrs.update(
+            self._parse_extra_properties(parsed_args.extra_properties))
         obj = client.create_segment(**attrs)
         display_columns, columns = _get_columns(obj)
-        data = utils.get_item_properties(obj, columns, formatters=_formatters)
+        data = utils.get_item_properties(obj, columns)
         return (display_columns, data)
 
 
@@ -195,7 +193,7 @@ class ListNetworkSegment(command.Lister):
                 ) for s in data))
 
 
-class SetNetworkSegment(command.Command):
+class SetNetworkSegment(common.NeutronCommandWithExtraArgs):
     _description = _("Set network segment properties")
 
     def get_parser(self, prog_name):
@@ -226,6 +224,8 @@ class SetNetworkSegment(command.Command):
             attrs['description'] = parsed_args.description
         if parsed_args.name is not None:
             attrs['name'] = parsed_args.name
+        attrs.update(
+            self._parse_extra_properties(parsed_args.extra_properties))
         client.update_segment(obj, **attrs)
 
 
@@ -248,5 +248,5 @@ class ShowNetworkSegment(command.ShowOne):
             ignore_missing=False
         )
         display_columns, columns = _get_columns(obj)
-        data = utils.get_item_properties(obj, columns, formatters=_formatters)
+        data = utils.get_item_properties(obj, columns)
         return (display_columns, data)
